@@ -22,6 +22,12 @@ class BaseConsumer(ABC):
     """
     set_consume_started_at = False
 
+    """
+    When the queue is empty, the process waits a couple seconds before looking for new jobs again.
+    This default can be overridden in case faster response times are needed.
+    """
+    wait_seconds_at_empty_queue = 10
+
     @property
     @abstractmethod
     def collection_name(self):
@@ -76,9 +82,11 @@ class BaseConsumer(ABC):
     def consume(
         self, end_at_empty_queue=False, end_at_disabled_consumer=False, batch_size=None
     ):
+        log.info("Started consume()")
         if not batch_size:
             batch_size = self.get_default_batch_size()
 
+        log.info(f"batch_size: {batch_size}")
         try:
             collection = Collection.objects.get(name=self.collection_name)
         except Collection.DoesNotExist:
@@ -89,14 +97,20 @@ class BaseConsumer(ABC):
             )
             return
 
+        log.info(f"collection: {collection.name}")
+
         while True:
             collection.refresh_from_db()
+            log.info(f"refreshed collection: {collection.name}")
             if not collection.consumer_enabled:
+                log.info(f"consumer not enabled for collection: {collection.name}")
                 if end_at_disabled_consumer:
                     break  # For testing purposes
-                sleep(10)
+                sleep(self.wait_seconds_at_empty_queue)
+                log.info(f"Waited {self.wait_seconds_at_empty_queue}")
                 continue
 
+            log.info(f"Starting transaction to lock records in {collection.name}")
             with transaction.atomic():
                 # This locks N records and iterates over them.
                 # Parallel workers simply lock the next N records
@@ -111,10 +125,12 @@ class BaseConsumer(ABC):
                 )
 
                 num_messages = messages.count()
+                log.info(f"Locked {num_messages} messages in {collection.name}")
                 if num_messages > 0:
+                    log.info(f"Locked {num_messages} messages in {collection.name}")
                     self.consume_iterator(messages.iterator())
 
-                if num_messages < batch_size:
-                    if end_at_empty_queue:
-                        break  # For testing purposes
-                    sleep(1)
+            if num_messages < batch_size:
+                if end_at_empty_queue:
+                    break  # For testing purposes
+                sleep(1)
