@@ -31,6 +31,12 @@ class Command(BaseCommand):
         with transaction.atomic():
             failed_queryset = FailedMessage.objects.for_collection(collection)
             num_failed_messages = failed_queryset.count()
+            start_message = (
+                f"Start moving {num_failed_messages} from the failed queue "
+                f"to the normal queue to be parsed again."
+            )
+            self.stdout.write(start_message)
+
             for failed_message in failed_queryset:
                 failed_message.move_to_ingress_queue()
 
